Enum sc_executor_common::wasm_runtime::InvokeMethod [−][src]
pub enum InvokeMethod<'a> {
Export(&'a str),
Table(u32),
TableWithWrapper {
dispatcher_ref: u32,
func: u32,
},
}Expand description
A method to be used to find the entrypoint when calling into the runtime
Contains variants on how to resolve wasm function that will be invoked.
Variants
Export(&'a str)Call function exported with this name.
Located function should have (u32, u32) -> u64 signature.
Tuple Fields of Export
0: &'a strTable(u32)Call a function found in the exported table found under the given index.
Located function should have (u32, u32) -> u64 signature.
Tuple Fields of Table
0: u32Call function by reference from table through a wrapper.
Invoked function (dispatcher_ref) function
should have (u32, u32, u32) -> u64 signature.
func will be passed to the invoked function as a first argument.
Fields of TableWithWrapper
dispatcher_ref: u32Wrapper for the call.
Function pointer, index into runtime exported table.
func: u32Extra argument for dispatch.
Common usage would be to use it as an actual wasm function pointer that should be invoked, but can be used as any extra argument on the callee side.
This is typically generated and invoked by the runtime itself.