[−][src]Trait sc_executor_common::wasm_runtime::WasmRuntime
A trait that defines an abstract wasm runtime.
This can be implemented by an execution engine.
Required methods
fn host_functions(&self) -> &[&'static dyn Function]
Return the host functions that are registered for this Wasm runtime.
fn call(&mut self, method: &str, data: &[u8]) -> Result<Vec<u8>, Error>
Call a method in the Substrate runtime by name. Returns the encoded result on success.
fn get_global_val(&self, name: &str) -> Result<Option<Value>, Error>
Get the value from a global with the given name.